pub struct InMessage {
pub type: i32,
pub rendez_vous_id: u32,
pub data: Vec<u8>,
pub error: String,
}Expand description
Message sent to application running in WASM from runtime.
Fields
type: i32rendez_vous_id: u32if message is a response to a previous outgoing message, this identifier will be the same as the outgoing message
data: Vec<u8>error: StringImplementations
Sourceimpl InMessage
impl InMessage
Sourcepub fn type(&self) -> InMessageType
pub fn type(&self) -> InMessageType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: InMessageType)
pub fn set_type(&mut self, value: InMessageType)
Sets type to the provided enum value.