pub struct OutMessage {
pub type: i32,
pub rendez_vous_id: u32,
pub data: Vec<u8>,
}Expand description
Message sent from application running in WASM to runtime.
Fields
type: i32rendez_vous_id: u32if message require a response, id that will be used to match response back to callee
data: Vec<u8>Implementations
Sourceimpl OutMessage
impl OutMessage
Sourcepub fn type(&self) -> OutMessageType
pub fn type(&self) -> OutMessageType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: OutMessageType)
pub fn set_type(&mut self, value: OutMessageType)
Sets type to the provided enum value.