pub struct EntityIndexConfig {
pub chain_index_min_depth: Option<u64>,
pub chain_index_depth_leeway: Option<u64>,
pub chain_index_deferred_interval_secs: Option<u64>,
pub chain_index_deferred_query_secs: Option<u64>,
pub chain_index_deferred_max_secs: Option<u64>,
pub pending_index: Option<MutationIndexConfig>,
pub chain_index: Option<MutationIndexConfig>,
pub garbage_collector: Option<EntityGarbageCollectorConfig>,
}Expand description
Configuration of the entity index
Fields
chain_index_min_depth: Option<u64>What is the minimum depth that a block needs to be the chain to be indexed. This is required to lower the odds that we are going to revert the block if our local chain forked.
CommitManagerConfig.operations_cleanup_after_block_depth
chain_index_depth_leeway: Option<u64>If specified, prevent indexing every new block on each commit. Operations will be kept in pending index for a bit longer and preventing the costly chain index modification.
chain_index_deferred_interval_secs: Option<u64>Specifies the interval at which new blocks in the chain get indexed.
New blocks may not necessarily get immediately indexed if they don’t
fall in the interval of chain_index_min_depth and
chain_index_depth_leeway.
Indexation can also be prevented if user queries were recently executed
(see chain_index_deferred_query_secs)
If ‘0’ is specified, deferred indexation is disabled and blocks are indexed when the chain layer emits events.
chain_index_deferred_query_secs: Option<u64>Specifies the minimum interval to wait before indexing chain blocks after receiving a user query. It prevents potential slow downs caused by chain indexation if a user query get executed frequently.
chain_index_deferred_max_secs: Option<u64>Specifies the maximum interval for which indexation may be blocked by incoming user queries.
pending_index: Option<MutationIndexConfig>Configuration for the in-memory traits index that are in the pending store
chain_index: Option<MutationIndexConfig>Configuration for the persisted traits index that are in the chain
garbage_collector: Option<EntityGarbageCollectorConfig>Configuration for the entity garbage collector.