DeleteOperationsMutation

Struct DeleteOperationsMutation 

pub struct DeleteOperationsMutation {
    pub operation_ids: Vec<u64>,
}
Deletes mutations of an entity that have an operation id specified in the given list. This mutation is used for index management purpose only since the mutations are not actually deleted from the chain. Since the chain indices are built in a semi-versioned way, this actually delete the mutations from the indices.

Fields

operation_ids: Vec<u64>