pub struct EntityQuery {
pub projections: Vec<Projection>,
pub paging: Option<Paging>,
pub ordering: Option<Ordering>,
pub watch_token: u64,
pub result_hash: u64,
pub include_deleted: bool,
pub programmatic: bool,
pub predicate: Option<Predicate>,
}Fields
projections: Vec<Projection>Optional projections on traits and fields to be returned.
paging: Option<Paging>Query paging requested.
ordering: Option<Ordering>Query ordering.
watch_token: u64Optional watch token if this query is to be used for watching.
result_hash: u64If specified, if results from server matches this hash, results will be
empty with the skipped_hash field set to true.
include_deleted: boolInclude deleted mutations matches. This can be used to return recently
modified entities that also include deletions. Deleted traits will
be included in the results but will have a deletion_date field
with the date of the deletion.
programmatic: boolIndicates that the query comes from an automated / programmatic logic. This is used since chain indexation may be deferred until no user queries got received for a while.
predicate: Option<Predicate>Main search predicate on individual traits of the entity.