pub struct TestMessage {Show 19 fields
pub string1: String,
pub string2: String,
pub string3: String,
pub struct1: Option<TestStruct>,
pub date1: Option<Timestamp>,
pub date2: Option<Timestamp>,
pub date3: Option<Timestamp>,
pub uint1: u32,
pub uint2: u32,
pub uint3: u32,
pub int1: i32,
pub int2: i32,
pub int3: i32,
pub ref1: Option<Reference>,
pub ref2: Option<Reference>,
pub grouped1: String,
pub grouped2: String,
pub map1: HashMap<String, String>,
pub fields: Option<Fields>,
}Fields
string1: Stringstring2: Stringstring3: Stringstruct1: Option<TestStruct>date1: Option<Timestamp>date2: Option<Timestamp>date3: Option<Timestamp>uint1: u32uint2: u32uint3: u32int1: i32int2: i32int3: i32ref1: Option<Reference>ref2: Option<Reference>grouped1: Stringgrouped2: Stringmap1: HashMap<String, String>fields: Option<Fields>Trait Implementations
Sourceimpl Clone for TestMessage
impl Clone for TestMessage
Sourcefn clone(&self) -> TestMessage
fn clone(&self) -> TestMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TestMessage
impl Debug for TestMessage
Sourceimpl Default for TestMessage
impl Default for TestMessage
Sourceimpl Message for TestMessage
impl Message for TestMessage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl NamedMessage for TestMessage
impl NamedMessage for TestMessage
Sourceimpl PartialEq for TestMessage
impl PartialEq for TestMessage
Sourcefn eq(&self, other: &TestMessage) -> bool
fn eq(&self, other: &TestMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TestMessage