pub struct DeleteOperationsMutation {
pub operation_ids: Vec<u64>,
}Expand description
Deletes mutations of an entity that have an operation id specified in the given list. This mutation is used for index management purpose only since the mutations are not actually deleted from the chain. Since the chain indices are built in a semi-versioned way, this actually delete the mutations from the indices.
Fields
operation_ids: Vec<u64>Trait Implementations
Sourceimpl Clone for DeleteOperationsMutation
impl Clone for DeleteOperationsMutation
Sourcefn clone(&self) -> DeleteOperationsMutation
fn clone(&self) -> DeleteOperationsMutation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteOperationsMutation
impl Debug for DeleteOperationsMutation
Sourceimpl Default for DeleteOperationsMutation
impl Default for DeleteOperationsMutation
Sourceimpl Message for DeleteOperationsMutation
impl Message for DeleteOperationsMutation
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DeleteOperationsMutation
impl PartialEq for DeleteOperationsMutation
Sourcefn eq(&self, other: &DeleteOperationsMutation) -> bool
fn eq(&self, other: &DeleteOperationsMutation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeleteOperationsMutation